@@ -13,9 +13,9 @@
 #' @examples \dontrun{
 #' plosword('Helianthus')
 #' plosword(list('monkey','Helianthus','sunflower','protein','whale'), 
-#'    vis = 'TRUE')
+#'    vis = TRUE)
 #' out <- plosword(list('monkey','replication','design','sunflower','whale'), 
-#'    vis = 'TRUE')
+#'    vis = TRUE)
 #' out[[1]] # results in a data frame 
 #' out[[2]] # results in a bar plot
 #' 
@@ -29,44 +29,46 @@ plosword <- function(terms, vis = FALSE,
 {
   Term = NULL
   No_Articles = NULL
-	url = 'http://api.plos.org/search'
-	
+  url = 'http://api.plos.org/search'
+  
   if (length(terms) == 1) {
-  args <- list(apikey = key)
-  if(!is.na(terms))
-    args$q <- terms
-  args$fl <- "id" # just ID field to speed up return of search results
-  args$wt <- "json"
-  tt <- getForm(url, 
-    .params = args,
-    .opts=callopts,
-    curl = curl)
-  numres <- fromJSON(I(tt))$response$numFound
-  names(numres) <- 'Number of articles with search term'
-  return(numres)
+    args <- list(apikey = key)
+    if(!is.na(terms))
+      args$q <- terms
+    args$fl <- "id" # just ID field to speed up return of search results
+    args$wt <- "json"
+    tt <- getForm(url, 
+                  .params = args,
+                  .opts=callopts,
+                  curl = curl)
+    numres <- fromJSON(I(tt))$response$numFound
+    names(numres) <- 'Number of articles with search term'
+    return(numres)
   }  
   else {
     search_ <- function(x) {
-        args <- list(apikey = key)
-        if(!is.na(x))
+      args <- list(apikey = key)
+      if(!is.na(x))
         args$q <- x
-        args$fl <- "id" # just ID field to speed up return of search results
-        args$wt <- "json"
-        tt <- getForm(url, 
-          .params = args,
-          .opts=callopts,
-          curl = curl)
-        numres <- fromJSON(I(tt))$response$numFound
-        return(numres)
+      args$fl <- "id" # just ID field to speed up return of search results
+      args$wt <- "json"
+      tt <- getForm(url, 
+                    .params = args,
+                    .opts=callopts,
+                    curl = curl)
+      numres <- fromJSON(I(tt))$response$numFound
+      return(numres)
     }
     temp <- ldply(terms, search_)
     names(temp) <- "No_Articles"
     temp$Term <- terms
     temp$Term <- as.character(temp$Term)
-      if (vis == "TRUE") {
-     ##   if(!require(ggplot2)) stop("must first install 'ggplot2' package.")
-        p <- ggplot(temp, aes(x=Term, y=No_Articles)) + geom_bar(stat="identity")
-      }
-    return(list(table = temp, plot = p))
+    if (vis) {
+      p <- ggplot(temp, aes(x=Term, y=No_Articles)) + 
+        geom_bar(stat="identity") +
+        theme_grey(base_size = 18)
+      return(list(table = temp, plot = p))
+    }
+    return( temp )
   }
 }
